**chrono-kit** is an open source python library for time series analysis and forecasting.

This project was started in 2023 by ODTU YZT.
## Documentation
See the [wiki](https://github.com/odtuyzt/time-series-analysis/wiki) for documentation.

Or take a look at the [examples](https://github.com/odtuyzt/time-series-analysis/tree/main/examples).

## Installation

### Dependencies

"chronokit" requires:
* torch 
* numpy
* scipy
* matplotlib
* python

### User Installation

    pip install chronokit
